==> request-tracker4_4.4.4+dfsg.orig-third-party-source.tar.gz: rt-4.4.4/devel/third-party/ckeditor-src/plugins/table/lang/fo.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'table', 'fo', {
	border: 'Bordabreidd',
	caption: 'Tabellfrágreiðing',
	cell: {
		menu: 'Meski',
		insertBefore: 'Set meska inn áðrenn',
		insertAfter: 'Set meska inn aftaná',
		deleteCell: 'Strika meskar',
		merge: 'Flætta meskar',
		mergeRight: 'Flætta meskar til høgru',
		mergeDown: 'Flætta saman',
		splitHorizontal: 'Kloyv meska vatnrætt',
		splitVertical: 'Kloyv meska loddrætt',
		title: 'Mesku eginleikar',
		cellType: 'Mesku slag',
		rowSpan: 'Ræð spenni',
		colSpan: 'Kolonnu spenni',
		wordWrap: 'Orðkloyving',
		hAlign: 'Horisontal plasering',
		vAlign: 'Loddrøtt plasering',
		alignBaseline: 'Basislinja',
		bgColor: 'Bakgrundslitur',
		borderColor: 'Bordalitur',
		data: 'Data',
		header: 'Header',
		yes: 'Ja',
		no: 'Nei',
		invalidWidth: 'Meskubreidd má vera eitt tal.',
		invalidHeight: 'Meskuhædd má vera eitt tal.',
		invalidRowSpan: 'Raðspennið má vera eitt heiltal.',
		invalidColSpan: 'Kolonnuspennið má vera eitt heiltal.',
		chooseColor: 'Vel'
	},
	cellPad: 'Meskubreddi',
	cellSpace: 'Fjarstøða millum meskar',
	column: {
		menu: 'Kolonna',
		insertBefore: 'Set kolonnu inn áðrenn',
		insertAfter: 'Set kolonnu inn aftaná',
		deleteColumn: 'Strika kolonnur'
	},
	columns: 'Kolonnur',
	deleteTable: 'Strika tabell',
	headers: 'Yvirskriftir',
	headersBoth: 'Báðir',
	headersColumn: 'Fyrsta kolonna',
	headersNone: 'Eingin',
	headersRow: 'Fyrsta rað',
	invalidBorder: 'Borda-stødd má vera eitt tal.',
	invalidCellPadding: 'Cell padding má vera eitt tal.',
	invalidCellSpacing: 'Cell spacing má vera eitt tal.',
	invalidCols: 'Talið av kolonnum má vera eitt tal størri enn 0.',
	invalidHeight: 'Tabell-hædd má vera eitt tal.',
	invalidRows: 'Talið av røðum má vera eitt tal størri enn 0.',
	invalidWidth: 'Tabell-breidd má vera eitt tal.',
	menu: 'Eginleikar fyri tabell',
	row: {
		menu: 'Rað',
		insertBefore: 'Set rað inn áðrenn',
		insertAfter: 'Set rað inn aftaná',
		deleteRow: 'Strika røðir'
	},
	rows: 'Røðir',
	summary: 'Samandráttur',
	title: 'Eginleikar fyri tabell',
	toolbar: 'Tabell',
	widthPc: 'prosent',
	widthPx: 'pixels',
	widthUnit: 'breiddar unit'
} );

==> request-tracker5_5.0.5+dfsg.orig-third-party-source.tar.gz: rt-5.0.5/devel/third-party/ckeditor-src/plugins/table/lang/fo.js <==
/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'fo', {
	border: 'Bordabreidd',
	caption: 'Tabellfrágreiðing',
	cell: {
		menu: 'Meski',
		insertBefore: 'Set meska inn áðrenn',
		insertAfter: 'Set meska inn aftaná',
		deleteCell: 'Strika meskar',
		merge: 'Flætta meskar',
		mergeRight: 'Flætta meskar til høgru',
		mergeDown: 'Flætta saman',
		splitHorizontal: 'Kloyv meska vatnrætt',
		splitVertical: 'Kloyv meska loddrætt',
		title: 'Mesku eginleikar',
		cellType: 'Mesku slag',
		rowSpan: 'Ræð spenni',
		colSpan: 'Kolonnu spenni',
		wordWrap: 'Orðkloyving',
		hAlign: 'Horisontal plasering',
		vAlign: 'Loddrøtt plasering',
		alignBaseline: 'Basislinja',
		bgColor: 'Bakgrundslitur',
		borderColor: 'Bordalitur',
		data: 'Data',
		header: 'Header',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'Ja',
		no: 'Nei',
		invalidWidth: 'Meskubreidd má vera eitt tal.',
		invalidHeight: 'Meskuhædd má vera eitt tal.',
		invalidRowSpan: 'Raðspennið má vera eitt heiltal.',
		invalidColSpan: 'Kolonnuspennið má vera eitt heiltal.',
		chooseColor: 'Vel'
	},
	cellPad: 'Meskubreddi',
	cellSpace: 'Fjarstøða millum meskar',
	column: {
		menu: 'Kolonna',
		insertBefore: 'Set kolonnu inn áðrenn',
		insertAfter: 'Set kolonnu inn aftaná',
		deleteColumn: 'Strika kolonnur'
	},
	columns: 'Kolonnur',
	deleteTable: 'Strika tabell',
	headers: 'Yvirskriftir',
	headersBoth: 'Báðir',
	headersColumn: 'Fyrsta kolonna',
	headersNone: 'Eingin',
	headersRow: 'Fyrsta rað',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Borda-stødd má vera eitt tal.',
	invalidCellPadding: 'Cell padding má vera eitt tal.',
	invalidCellSpacing: 'Cell spacing má vera eitt tal.',
	invalidCols: 'Talið av kolonnum má vera eitt tal størri enn 0.',
	invalidHeight: 'Tabell-hædd má vera eitt tal.',
	invalidRows: 'Talið av røðum má vera eitt tal størri enn 0.',
	invalidWidth: 'Tabell-breidd má vera eitt tal.',
	menu: 'Eginleikar fyri tabell',
	row: {
		menu: 'Rað',
		insertBefore: 'Set rað inn áðrenn',
		insertAfter: 'Set rað inn aftaná',
		deleteRow: 'Strika røðir'
	},
	rows: 'Røðir',
	summary: 'Samandráttur',
	title: 'Eginleikar fyri tabell',
	toolbar: 'Tabell',
	widthPc: 'prosent',
	widthPx: 'pixels',
	widthUnit: 'breiddar unit'
} );
